@@ -16,19 +16,19 @@ from datetime import datetime
 from typing import List
 
 from .literals import (
-    AnomalySeverity,
-    AnomalyStatus,
-    CloudWatchMetricsStat,
-    CostEstimationServiceResourceState,
-    CostEstimationStatus,
-    EventClass,
-    EventDataSource,
-    InsightFeedbackOption,
-    InsightSeverity,
-    InsightStatus,
-    InsightType,
-    OptInStatus,
-    ServiceName,
+    AnomalySeverityType,
+    AnomalyStatusType,
+    CloudWatchMetricsStatType,
+    CostEstimationServiceResourceStateType,
+    CostEstimationStatusType,
+    EventClassType,
+    EventDataSourceType,
+    InsightFeedbackOptionType,
+    InsightSeverityType,
+    InsightStatusType,
+    InsightTypeType,
+    OptInStatusType,
+    ServiceNameType,
 )
 
 if sys.version_info >= (3, 8):
@@ -185,7 +185,7 @@ CloudWatchMetricsDetailTypeDef = TypedDict(
         "MetricName": str,
         "Namespace": str,
         "Dimensions": List["CloudWatchMetricsDimensionTypeDef"],
-        "Stat": CloudWatchMetricsStat,
+        "Stat": CloudWatchMetricsStatType,
         "Unit": str,
         "Period": int,
     },
@@ -329,8 +329,8 @@ EventTypeDef = TypedDict(
         "Time": datetime,
         "EventSource": str,
         "Name": str,
-        "DataSource": EventDataSource,
-        "EventClass": EventClass,
+        "DataSource": EventDataSourceType,
+        "EventClass": EventClassType,
         "Resources": List["EventResourceTypeDef"],
     },
     total=False,
@@ -340,7 +340,7 @@ GetCostEstimationResponseTypeDef = TypedDict(
     "GetCostEstimationResponseTypeDef",
     {
         "ResourceCollection": "CostEstimationResourceCollectionFilterTypeDef",
-        "Status": CostEstimationStatus,
+        "Status": CostEstimationStatusType,
         "Costs": List["ServiceResourceCostTypeDef"],
         "TimeRange": "CostEstimationTimeRangeTypeDef",
         "TotalCost": float,
@@ -362,7 +362,7 @@ InsightFeedbackTypeDef = TypedDict(
     "InsightFeedbackTypeDef",
     {
         "Id": str,
-        "Feedback": InsightFeedbackOption,
+        "Feedback": InsightFeedbackOptionType,
     },
     total=False,
 )
@@ -411,9 +411,9 @@ ListEventsFiltersTypeDef = TypedDict(
     {
         "InsightId": str,
         "EventTimeRange": "EventTimeRangeTypeDef",
-        "EventClass": EventClass,
+        "EventClass": EventClassType,
         "EventSource": str,
-        "DataSource": EventDataSource,
+        "DataSource": EventDataSourceType,
         "ResourceCollection": "ResourceCollectionTypeDef",
     },
     total=False,
@@ -443,7 +443,7 @@ class ListEventsResponseTypeDef(
 ListInsightsAnyStatusFilterTypeDef = TypedDict(
     "ListInsightsAnyStatusFilterTypeDef",
     {
-        "Type": InsightType,
+        "Type": InsightTypeType,
         "StartTimeRange": "StartTimeRangeTypeDef",
     },
 )
@@ -451,7 +451,7 @@ ListInsightsAnyStatusFilterTypeDef = TypedDict(
 ListInsightsClosedStatusFilterTypeDef = TypedDict(
     "ListInsightsClosedStatusFilterTypeDef",
     {
-        "Type": InsightType,
+        "Type": InsightTypeType,
         "EndTimeRange": "EndTimeRangeTypeDef",
     },
 )
@@ -459,7 +459,7 @@ ListInsightsClosedStatusFilterTypeDef = TypedDict(
 ListInsightsOngoingStatusFilterTypeDef = TypedDict(
     "ListInsightsOngoingStatusFilterTypeDef",
     {
-        "Type": InsightType,
+        "Type": InsightTypeType,
     },
 )
 
@@ -520,7 +520,7 @@ NotificationChannelTypeDef = TypedDict(
 OpsCenterIntegrationConfigTypeDef = TypedDict(
     "OpsCenterIntegrationConfigTypeDef",
     {
-        "OptInStatus": OptInStatus,
+        "OptInStatus": OptInStatusType,
     },
     total=False,
 )
@@ -528,7 +528,7 @@ OpsCenterIntegrationConfigTypeDef = TypedDict(
 OpsCenterIntegrationTypeDef = TypedDict(
     "OpsCenterIntegrationTypeDef",
     {
-        "OptInStatus": OptInStatus,
+        "OptInStatus": OptInStatusType,
     },
     total=False,
 )
@@ -568,8 +568,8 @@ ProactiveAnomalySummaryTypeDef = TypedDict(
     "ProactiveAnomalySummaryTypeDef",
     {
         "Id": str,
-        "Severity": AnomalySeverity,
-        "Status": AnomalyStatus,
+        "Severity": AnomalySeverityType,
+        "Status": AnomalyStatusType,
         "UpdateTime": datetime,
         "AnomalyTimeRange": "AnomalyTimeRangeTypeDef",
         "PredictionTimeRange": "PredictionTimeRangeTypeDef",
@@ -585,8 +585,8 @@ ProactiveAnomalyTypeDef = TypedDict(
     "ProactiveAnomalyTypeDef",
     {
         "Id": str,
-        "Severity": AnomalySeverity,
-        "Status": AnomalyStatus,
+        "Severity": AnomalySeverityType,
+        "Status": AnomalyStatusType,
         "UpdateTime": datetime,
         "AnomalyTimeRange": "AnomalyTimeRangeTypeDef",
         "PredictionTimeRange": "PredictionTimeRangeTypeDef",
@@ -603,8 +603,8 @@ ProactiveInsightSummaryTypeDef = TypedDict(
     {
         "Id": str,
         "Name": str,
-        "Severity": InsightSeverity,
-        "Status": InsightStatus,
+        "Severity": InsightSeverityType,
+        "Status": InsightStatusType,
         "InsightTimeRange": "InsightTimeRangeTypeDef",
         "PredictionTimeRange": "PredictionTimeRangeTypeDef",
         "ResourceCollection": "ResourceCollectionTypeDef",
@@ -618,8 +618,8 @@ ProactiveInsightTypeDef = TypedDict(
     {
         "Id": str,
         "Name": str,
-        "Severity": InsightSeverity,
-        "Status": InsightStatus,
+        "Severity": InsightSeverityType,
+        "Status": InsightStatusType,
         "InsightTimeRange": "InsightTimeRangeTypeDef",
         "PredictionTimeRange": "PredictionTimeRangeTypeDef",
         "ResourceCollection": "ResourceCollectionTypeDef",
@@ -632,8 +632,8 @@ ReactiveAnomalySummaryTypeDef = TypedDict(
     "ReactiveAnomalySummaryTypeDef",
     {
         "Id": str,
-        "Severity": AnomalySeverity,
-        "Status": AnomalyStatus,
+        "Severity": AnomalySeverityType,
+        "Status": AnomalyStatusType,
         "AnomalyTimeRange": "AnomalyTimeRangeTypeDef",
         "SourceDetails": "AnomalySourceDetailsTypeDef",
         "AssociatedInsightId": str,
@@ -646,8 +646,8 @@ ReactiveAnomalyTypeDef = TypedDict(
     "ReactiveAnomalyTypeDef",
     {
         "Id": str,
-        "Severity": AnomalySeverity,
-        "Status": AnomalyStatus,
+        "Severity": AnomalySeverityType,
+        "Status": AnomalyStatusType,
         "AnomalyTimeRange": "AnomalyTimeRangeTypeDef",
         "SourceDetails": "AnomalySourceDetailsTypeDef",
         "AssociatedInsightId": str,
@@ -661,8 +661,8 @@ ReactiveInsightSummaryTypeDef = TypedDict(
     {
         "Id": str,
         "Name": str,
-        "Severity": InsightSeverity,
-        "Status": InsightStatus,
+        "Severity": InsightSeverityType,
+        "Status": InsightStatusType,
         "InsightTimeRange": "InsightTimeRangeTypeDef",
         "ResourceCollection": "ResourceCollectionTypeDef",
         "ServiceCollection": "ServiceCollectionTypeDef",
@@ -675,8 +675,8 @@ ReactiveInsightTypeDef = TypedDict(
     {
         "Id": str,
         "Name": str,
-        "Severity": InsightSeverity,
-        "Status": InsightStatus,
+        "Severity": InsightSeverityType,
+        "Status": InsightStatusType,
         "InsightTimeRange": "InsightTimeRangeTypeDef",
         "ResourceCollection": "ResourceCollectionTypeDef",
         "SsmOpsItemId": str,
@@ -769,8 +769,8 @@ ResourceCollectionTypeDef = TypedDict(
 SearchInsightsFiltersTypeDef = TypedDict(
     "SearchInsightsFiltersTypeDef",
     {
-        "Severities": List[InsightSeverity],
-        "Statuses": List[InsightStatus],
+        "Severities": List[InsightSeverityType],
+        "Statuses": List[InsightStatusType],
         "ResourceCollection": "ResourceCollectionTypeDef",
         "ServiceCollection": "ServiceCollectionTypeDef",
     },
@@ -790,7 +790,7 @@ SearchInsightsResponseTypeDef = TypedDict(
 ServiceCollectionTypeDef = TypedDict(
     "ServiceCollectionTypeDef",
     {
-        "ServiceNames": List[ServiceName],
+        "ServiceNames": List[ServiceNameType],
     },
     total=False,
 )
@@ -798,7 +798,7 @@ ServiceCollectionTypeDef = TypedDict(
 ServiceHealthTypeDef = TypedDict(
     "ServiceHealthTypeDef",
     {
-        "ServiceName": ServiceName,
+        "ServiceName": ServiceNameType,
         "Insight": "ServiceInsightHealthTypeDef",
     },
     total=False,
@@ -825,7 +825,7 @@ ServiceResourceCostTypeDef = TypedDict(
     "ServiceResourceCostTypeDef",
     {
         "Type": str,
-        "State": CostEstimationServiceResourceState,
+        "State": CostEstimationServiceResourceStateType,
         "Count": int,
         "UnitCost": float,
         "Cost": float,
